#include "gtk.h"
/* XPM */
static const char *const xpm_icon_0[] = {
/* columns rows colors chars-per-pixel */
"128 128 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXlXlXlXlXlXlXlXlXlXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXkXlXbXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXbXlXkXlXlXlXlXkXzXbXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXvXkXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXkXcXvXeX6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X7XtXnXxXkXlXlXjXbXxXwX6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X7XuXmXzXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXkXxXgXc.i                                                                                               k D.zXxXlXkXcXpXi.9                                                                                               N E.vXzXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXvXe.  O X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X . X   m.bXkXlXzX$.  O X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X .     R.bXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXkXNX;X4 o X                                                                                               X X y eXxXCX'.- o X                                                                                               . . c kXzXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXjXCX.X  +                                                                                                   X   6XcXFXK.  @                                                                                                     @ hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXjXCX.X  +                   X o .                                                     . o X                 X   6XcXFXJ.  @                 X X X X                                                   . o .                     O hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXjXCX.X  +                                                                                                   X   6XcXFXJ.  @                                                                                                     O hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXjXCX.X  +             X   % !.GXH                                                 X   / UXW.4   X           X   6XcXFXJ.  @           X   q J.xXjXS.1   .                                       .     *.UXs.    .               o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXjXCX.X  +           .   , _.UXUXQ                                               .   > .XUX%X8   X           X   6XcXFXJ.  @         X   = [.UX$X-XUX%X  o .                                       X ,.UXUXS.    .               o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXjXCX.X  +           X   y.vX/.LX!                                               .   G UXUX@X7   X           X   6XcXFXJ.  @         O   P UXm.    E.tXz   X                                       v BX(.mXF.    .               o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXjXCX.X  +           X   z i @.UXQ                                                 o _.vXyX>X5   X           X   6XcXFXJ.  @         +   ( UXX.    + k :   .                                       = D p VXS.    .               o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXjXCX.X  +             X     >.UXQ                                                 g PXD.).7X3   X           X   6XcXFXJ.  @         +   ( UX{ Y m.-.%   .                                         .   f CXS.    .               o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXjXCX.X  +               @   ;.UXQ                                                 G.zXm &X3X3   X           X   6XcXFXJ.  @         +   ' UX$XwXUXUXC.  o                                         o   d CXS.    .               o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXjXCX.X  +               +   ;.UXQ                                               3 HXI.@ ,X1X4   X           X   6XcXFXJ.  @         +   ` UXoXv j aXvX9   X                                       X   s CXS.    .               o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXjXCX.X  +               +   ;.UXQ                                           .   u.GXs X =X>X>   X           X   6XcXFXJ.  @         +   ( UX+.    M.NXD   o                                       X   s CXS.    .               o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXjXCX.X  +               +   ;.UXQ                                           X   =XUXvXmXDXUXp..   .         X   6XcXFXJ.  @         +   ( UXX.    x.VXD   o                                       X   s CXS.    .               o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXjXCX.X  +               +   -.UXE                                           .   y.^./.{.zXFX&.              X   6XcXFXJ.  @         O   Z KX).< > uXzX0   X                                       X   s MXZ.    .               o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXjXCX.X  +               +   4.UX(                                                     & 7XrX<   X           X   6XcXFXJ.  @         .   o N.UXBXKXUXl.  O                                         o   g UXT.    .               o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXjXCX.X  +               o   T ].m                                               . o   ; h.x.:   .           X   6XcXFXJ.  @           X   & :._.Q.#.  .                                           X   9 R.-.    .               o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXjXCX.X  +                 X       .                                                 .         .             X   6XcXFXJ.  @             .           X                                               .                           o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXjXCX.X  +                   o # X                                                       + @ .               X   6XcXFXJ.  @               . + # # O                                                   . # O                     O hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXjXCX X  +                                                                                                   X   6XcXFXJ.  @                                                                                                     o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXjXCXoX  O                                                                                                   .   7XcXDXI.  +                                                                                                     = hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXkXnX7Xb   X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X .   J pXzXMX*Xa   X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X     ) zXzXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXjXBXT., X                                                                                               O 6 .XmXkXhXVXn.=                                                                                                 + y <XbXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXjXNX:X..c k l k k k k k k k k k k k k k k k k k k k k k k k k k k k k k k k k k k k k k k k k k l k b %.7XmXkXlXlXjXBXoX_ z k l k k k k k k k k k k k k k k k k k k k k k k k k k k k k k k k k k k k k k k k k k l k M 1.uXnXkXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXkXxXAXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXZXzXkXlXlXlXlXkXvXSXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXGXCXlXkXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXkXgXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXgXkXlXlXlXlXlXlXkXgXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXdXpXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXaXkXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXjXZXLXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXLXAXjXkXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXxXvXz./ U T Y Y Y Y Y Y Y Y Y Y Y Y Y T Y ~ a.jXbXkXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXsXH *                                       % b 8XvXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXmX5.    o O o o o o o o o o o o o o o o o o o     O.zXzXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXBXy   .                                       .   : hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXfXfXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXdXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXhXfXfXhXlXlXlXlXlXlXlXlXlXlXlXlXjXVX3   .               X + + + X                   X hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXBXLXLXZXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXnXIXDXxXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXVXLXLXVXjXlXlXlXlXlXlXlXlXlXlXlXjXVX4   .             X           X                 o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXzXxX|.f.h.^.bXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXmX>X7.H.iXxXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXzXzX'.d.j.'.mXjXlXlXlXlXlXlXlXlXlXlXjXVX4   .               0 o.<.{ :   .               o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXvXV.@     % r.MXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXzXkX*.  k 3XnXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXmXb.O     , N.VXhXlXlXlXlXlXlXlXlXlXjXVX4   .             i 7XUXUXUX}.<   .             o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXmX1Xw 0 W.oXt % 2XxXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXBX=X,   G 6XbXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXnX,X3 1 /.'.= u gXkXkXlXlXlXlXlXlXlXlXjXVX4   .             G.UX4.e c.UX5.                o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXZX[.  4.HXJX5.@ L.mXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXxXw.  % N 6XnXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXbX5Xf.!.VXHXT 3 >XcXjXlXlXlXlXlXlXlXlXjXVX4   .             pXwX    < 8.~ .               o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXAX[.  0.AXzXp.@ D.mXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXbXrX< N G j 9XnXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXxXxXzX3X: f zXjXkXlXlXlXlXlXlXlXlXjXVX4   .             gX0X  t q                     o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXAX[.  g.b.d.y.# D.mXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXx.@ b.G j 9XnXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXAXo.  & E.mXjXlXlXlXlXlXlXlXlXlXjXVX4   .             dXtX9.UXUXG.$   .             o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXAX[.  M.I z e.% D.mXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXkXe k qXc k 7XbXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXdXZXX., : J.mXjXlXlXlXlXlXlXlXlXlXjXVX4   .           . eXUX`.u.5XUXQ   .             o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXAX[.  d.C.c.t.# D.mXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXbXY.X T.DXN M aXnXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXxXMXkXAX5X0 3 9XzXkXlXlXlXlXlXlXlXlXjXVX4   .             aXfX5   R IXj.                o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXAX[.  8.UXVXp.# D.mXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXNXP o 6.9.e 2 Y.xXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXxXiX*XpXfXlXs.# G.BXhXlXlXlXlXlXlXlXlXjXVX4   .             fX0X  # n zXS..               o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXZX|.  @.NXPXo.@ Q.nXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXMXI -     o   &.jXzXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXZX^.t C.JXHX&.% U.NXhXlXlXlXlXlXlXlXlXjXVX4   .             8XaX1   Y UXd.                o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXvXtXS   #.>.@ 0 sXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXxX-X}.%X`.l a %XvXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXmX-X4 # 1.;.. d dXkXkXlXlXlXlXlXlXlXlXjXVX4   .             8.UX}.9.5XUXG   .             o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXbX$XV     x [.nXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXMXBXFXsXz g eXnXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXnX_.f     m XXnXjXlXlXlXlXlXlXlXlXlXjXVX4   .             & b.IXUXmX*..   .             o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXdX7X8XiXbXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXhXjXgX0X0XhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXcXpX6X8XpXbXkXlXlXlXlXlXlXlXlXlXlXjXVX4   .               . 2 6 ,     .               o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXmXmXvXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXbXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXvXmXmXvXkXlXlXlXlXlXlXlXlXlXlXlXjXVX4   .             .                             o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXkXlXlXlXlXlXlXlXlXlXlXlXlXlXjXVX4   .                 . . .                     o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXVX4   .                                           o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXVX4   .                                           o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXVX4   .                                           o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXVX4   .                                           o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXVX4   .                                           o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXVX4   .                                           o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXVX4   .                                           o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXVX4   .                                           o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXVX4   .                                           o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXVX4   .                                           o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXVX4   .                                           o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXVX4   .                                           o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXxXxXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXxXxXxXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXxXxXzXlXlXlXlXlXlXlXlXlXlXlXlXjXVX4   .                                           o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXxXhXhXzXvXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXvXkXhXkXcXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXxXhXjXzXcXkXlXlXlXlXlXlXlXlXlXlXjXVX4   .             X O O O O + .                 o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXbX1X! + o J =XvXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXvXN.0   5 v.lXzXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXbX:XY o o ~ 6XcXkXlXlXlXlXlXlXlXlXlXjXVX4   .             C.UXPXIXJXUXz   X             o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXcXpXT   E ^   a jXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXbXQ.  8 X.i   T.CXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXzXpXB   ~ T   L BXhXlXlXlXlXlXlXlXlXlXjXVX4   .             H.LXR.n.m.S.9   .             o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXCX.X  { bXLX` + (.bXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXnXp.x W.UX).  1.cXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXMX&XZ =.cXSXB 7 3XxXjXlXlXlXlXlXlXlXlXjXVX4   .             P.vXa         .               o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXAX[.  9.JXnXi.@ D.mXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXyX6XgXUX^.  7.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXgX7XyXVXMXx 2 eXlXkXlXlXlXlXlXlXlXlXjXVX4   .             P.vXq     X X                 o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXAX[.  t.=X+Xy.@ F.mXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXnXrXl.z > oXNXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXzXmXQ.o.  -.BXhXlXlXlXlXlXlXlXlXlXjXVX4   .             G.AXV.c.8.4   X               o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXAX[.  v.| I e.% D.mXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXBXOX    =.lXzXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXsXGXb   7 =XvXkXlXlXlXlXlXlXlXlXlXjXVX4   .             F.UXUXLXUX#X1   .             o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXAX[.  b.{ E r.$ D.mXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXxXaX`.!   P.NXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcX=Xj.O U xXjXlXlXlXlXlXlXlXlXlXjXVX4   .             w.-X[ $ k.UX .                o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXAX].  q.xXpXp.@ D.mXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXxXxXlXDX%X1 U sXcXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXcXlXNXnXX.@ (.mXhXlXlXlXlXlXlXlXlXjXVX4   .             o +     M BXM.                o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXAX].  6.LXGX0.@ J.mXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXbXz.u.lXZXyXc x eXbXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXNX$X-.%XZXZXd.+ A.VXgXlXlXlXlXlXlXlXlXjXVX4   .             y t .   N VXm.                o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXNX;X4 d oX6Xh @ ;XcXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXMX/   b.uXb.  +.kXxXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXZX/.  P <X,Xg > &XvXjXlXlXlXlXlXlXlXlXjXVX4   .             !.UX .% v.UX[                 o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXcXg.      . -.MXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcX&Xi   X   t @XNXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXlXgX>.      . 4.VXhXlXlXlXlXlXlXlXlXlXjXVX4   .             l hXUXUXUX X,   .             o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXxXkXT.=.-.Z.xXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXnX-Xq.$.9.;XnXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXvXsXA.&.;.G.vXkXlXlXlXlXlXlXlXlXlXlXjXVX4   .               g y.n.3.1   X               o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXkXVXIXIXAXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXbXJXUXKXbXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXlXAXUXIXZXjXlXlXlXlXlXlXlXlXlXlXlXjXVX4   .             X           X                 o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXgXdXdXgXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXfXdXfXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXgXdXdXgXlXlXlXlXlXlXlXlXlXlXlXlXjXVX4   .               o @ # @ X                   o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXVX3   .                                           X hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXBXu   .                                       .   > hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXmX7.    o O o o o o o o o o o o o o o o o o o     +.zXzXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXlXlXlXkXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXkXlXlXzXdXK =                                       % m 9XvXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXnXMXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXMXzXlXkXxXMXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXMXvXkXlXlXxXbXv.( U T Y Y Y Y Y Y Y Y Y Y Y Y Y T U ^ s.kXbXkXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXcX3X-X:X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X:X-XhXlXxXiX*X:X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X:X=X0XcXkXlXkXhXCXLXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXLXAXjXkXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXjXlXlXlXjXMXG.d.l.k.k.k.k.k.k.k.k.k.k.k.k.k.k.k.k.k.k.k.k.l.f.pXzXmX,Xi.x.k.k.k.k.k.k.k.k.k.k.k.k.k.k.k.k.k.k.k.k.z.p.'.BXjXlXlXlXgXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXgXkXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXFXMXkXlXlXlXxX0X5X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X5XjXlXxXsX4X7X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X4XyXxXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXxXhXx j l k k k k k k k k k k k k k k k k k k l j G M.mXlXlXlXlXbXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXzXlXlXxXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXcXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXxXhX                                                @ ^ vXjXlXlXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXlXlXlXlXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXxXhX+   X X X X X X X X X X X X X X X X X X X X X X   # x.CXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXxXhXo                                               o   ~ LXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXxXhXo                           + # o               o   U PXdXlXlXlXlXlXlXlXlXlXlXlXlXlXjXsXgXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXgXdXdXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXsXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXxXhXo                         o       .             o   Y PXdXlXlXlXlXlXlXlXlXlXlXlXlXjXnXUXFXxXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXkXZXUXIXCXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXmXUXZXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXxXhXo                       o   3.Z.S   .           o   Y PXdXlXlXlXlXlXlXlXlXlXlXlXjXMX+X` j.tXcXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXxXfXD.%.:.L.nXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXmXoX' G.zXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXxXhXo                     X   l FXUX9.  .           o   Y PXdXlXlXlXlXlXlXlXlXlXlXkXxXhX..  l 4XnXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXkXzX6.      # a.CXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXMX+Xq   ` zXlXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXxXhXo                     @   V.UXJX>.  .           o   Y PXdXlXlXlXlXlXlXlXlXlXlXjXBX$X%   F 6XbXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXBX.X# v -X-X, q yXlXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXvX$X3 5 : X.xXlXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXxXhXo                   o   y uXMXHX2.  .           o   Y PXdXlXlXlXlXlXlXlXlXlXlXzXzX<.X ; M 6XnXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXmX,Xq.|.VXCX] , .XbXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbX3X<./.; } cXlXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXxXhXo                   @   9.UXl.MX5.  .           o   Y PXdXlXlXlXlXlXlXlXlXlXkXbX0X= F K h 9XnXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXcXxXkXcXZ 3 ,XcXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXZX;X*  .cXlXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXxXhXo                 X   < 8X'. .AX5.  .           o   Y PXdXlXlXlXlXlXlXlXlXlXlXbXi.% S.D j 9XnXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXhXBX~.  J VXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXBX&X*  .cXlXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXxXhXo                 O   { UX/ R LX7.  .           o   Y PXdXlXlXlXlXlXlXlXlXlXxXgX5 n rXx k 6XbXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXmX<X7 > OXvXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXBX&X*  .cXlXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXxXhXo               .   $ .X=X  Z JX$.  X           o   Y PXdXlXlXlXlXlXlXlXlXkXbXA.O ].DXB M sXnXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXzXiXD   N.CXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXBX&X*  .cXlXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXxXhXo               o   N IX6Xx.|.UXoX9   .         o   Y PXdXlXlXlXlXlXlXlXlXjXNXG . } | 7 = C.xXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXjXcX#.  1.bXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXBX&X*  .cXlXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXxXhXo               o   N yXxXSXGXUXmXb   X         o   Y PXdXlXlXlXlXlXlXlXlXjXMX~ 6 & $ @   >.kXzXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXBXh.  ..ZXAXCXxXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXBX&X=  .cXlXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXxXhXo                   # w e < &.LXi.  .           o   Y PXdXlXlXlXlXlXlXlXlXlXzX8X>X9X$Xl s >XbXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXBX|.5   ) &...3.8XxXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXBX&X& | cXlXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXxXhXo                 .         Q SX>.  .           o   Y PXdXlXlXlXlXlXlXlXlXlXlXnXmXZXpXV n eXnXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXAXY.; O O .   9 =XcXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXBX*X: X.cXlXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXxXhXo                     . . . X O X               o   Y PXdXlXlXlXlXlXlXlXlXlXlXkXkXkXkXhXhXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXhXgXgXgXgXhXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXhXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXxXhXo                                               o   Y PXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXxXxXxXxXxXxXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXxXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXxXhXo                                               o   Y PXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXxXhXo                                               o   R PXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXxXhXo                                             . X X 1.FXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXxXhX+   X X X X X X X X X X X X X X X X X X X X X .   a 0XzXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXxXhX                                              %  .>XnXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlX6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X9XgXMXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXnXxXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX"
};

/* XPM */
static const char *const xpm_icon_1[] = {
/* columns rows colors chars-per-pixel */
"96 96 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXjXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXjXlXlXlXlXkXjXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXkXlXlXlXlXlX",
"lXlXlXlXkXzXNXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXCXMXlXlXlXkXxXBXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXCXmXkXlXlXlXlX",
"lXlXlXkXxXzXv.B j l k k k k k k k k k k k k k k k k k k k k k k k k k k k k k k k k l j F L.bXlXjXvXdXr.b j l k k k k k k k k k k k k k k k k k k k k k k k k k k k k k k k k l j T '.MXkXlXlXlX",
"lXlXlXkXmX4.                                                                                v.mXjXzX_                                                                               + !.mXkXlXlX",
"lXlXkXbX9X:   o X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X o   i hXVX.X  . o X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X O   H CXhXlXlX",
"lXlXkXnX4X  .             . .                                           . . .           .   : fXAX).  O           . .   . .                                     . . .             X   j ZXhXlXlX",
"lXlXkXnX4X              X                                                               .   , fXAX_.  o         .           .                                 X                   X   l ZXhXlXlX",
"lXlXkXnX4X            X   m MXr.  X                                 .   % 5X.X=   .     .   , fXAX).  O       X   b :XmXXXp   X                             X   ; <X XX   .       X   k ZXhXlXlX",
"lXlXkXnX4X          X   D xXUXb.  X                                 O   +.UX4X:   .     .   > fXAX).  O     .   = 0X4X .hX6X    .                         .   4 ;XUX<X+   .       X   k ZXhXlXlX",
"lXlXkXnX4X          o   E &.*XN.  X                               .   + %XLX-X:   .     .   > fXAX).  O     X   g UXm   w &.;   .                         .   i 4.N.3XO   .       X   k ZXhXlXlX",
"lXlXkXnX4X            .     <XB.  X                               o   T xXH.2X:   .     .   > fXAX).  O     X   h UXU 2.-.O   .                                   j.7Xo   .       X   k ZXhXlXlX",
"lXlXkXnX4X                  <XB.  X                               .   =XC.9.eX>   .     .   > fXAX).  O     X   j LX&X2XUXA.  o                               o   x.6Xo   .       X   k ZXhXlXlX",
"lXlXkXnX4X                  <XB.  X                             .   b cX, -.7Xo   .     .   > fXAX).  O     X   h UX=.  M.sX:   X                             o   z.6Xo   .       X   k ZXhXlXlX",
"lXlXkXnX4X                  <XB.  X                             O   m.UXF.5XGXE   X     .   > fXAX).  O     o   j UXl   $.aX0   X                             o   z.6Xo   .       X   k ZXhXlXlX",
"lXlXkXnX4X                  :XM.  X                             o   | /._.eXHX)   X     .   > fXAX).  O     X   8 ZXc.o  XwXO   .                             o   k.3Xo   .       X   k ZXhXlXlX",
"lXlXkXnX4X                  wXH.  X                               .       p.pX$   .     .   > fXAX).  O       X   ;.LXIXNX(   o                               o   N.pXo   .       X   k ZXhXlXlX",
"lXlXkXnX4X                  g e                                     . o   0 k O         .   , fXAX).  O             u C 0   .                                 .   q j .           X   k ZXhXlXlX",
"lXlXkXnX4X                      .                                       .               .   , fXAX_.  o           .       X                                     .                 X   l ZXhXlXlX",
"lXlXkXnX4X  .               X X                                           . X           .   : fXAX).  O             X o X                                         . X             X   j ZXhXlXlX",
"lXlXkXbX9X;   X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X o   u hXVX X  X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X O   G CXhXlXlX",
"lXlXlXkXnX1.                                                                                z.mXjXlX(                                                                               O E.mXjXlXlX",
"lXlXlXkXxXlXz.b a d s s s s s s s s s s s s s s s s s s s s s s s s s s s s s s s s d a C G.bXlXjXvXaXq.l a d s s s s s s s s s s s s s s s s s s s s s s s s s s s s s s s s d a L (.mXkXlXlXlX",
"lXlXlXlXkXzXNXBXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXBXMXlXlXlXkXxXNXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXBXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXnXkXlXlXlXlX",
"lXlXlXlXlXkXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXlXlXlXlXkXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXgXjXCXDXDXDXDXDXDXDXDXDXDXDXDXDXDXCXkXjXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXnXgXI.M.N.N.N.N.N.N.N.N.N.N.N.N.M.Y.jXnXkXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXvX8XD                                 J qXcXkXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXBXo.  o + + + + + + + + + + + + + + o   %.VXjXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXhXfXgXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXgXfXhXlXlXlXlXlXlXlXlXlXjXVXs   o           o + + X           o   k ZXhXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXZXLXDXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXGXFXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXSXLXAXkXlXlXlXlXlXlXlXlXjXVXs   X         .         .         X   k ZXhXlXlX",
"lXlXlXlXlXlXlXlXlXlXkXxXzXL.3.N.gXxXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXcXj.v.dXxXkXlXlXlXlXlXlXlXlXlXlXlXlXlXkXcXjXA.3.J.xXlXlXlXlXlXlXlXlXjXVXs   X       .   b r.4.7   X       X   k ZXhXlXlX",
"lXlXlXlXlXlXlXlXlXlXkXnXr.  u o ] mXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXBX{.  q rXvXkXlXlXlXlXlXlXlXlXlXlXlXlXkXkXbXX.  u   e.ZXhXlXlXlXlXlXlXjXVXs   X     X   D SXgXmXjX9   .     X   k ZXhXlXlX",
"lXlXlXlXlXlXlXlXlXkXcXaX, -.UXd.& :XnXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXBX .  B tXcXkXlXlXlXlXlXlXlXlXlXlXlXlXkXvXtXP f.UX} p jXzXkXlXlXlXlXlXjXVXs   X     X   ].3X  3 <X~   X     X   k ZXhXlXlX",
"lXlXlXlXlXlXlXlXlXkXvXyXO N.UXE.3 {.NXjXlXlXlXlXlXlXlXlXlXlXlXlXlXjXMX=X3 M c tXcXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXsXlXZXP m nXkXkXlXlXlXlXlXjXVXs   X     X   <XL.  q @ #         X   k ZXhXlXlX",
"lXlXlXlXlXlXlXlXlXkXvXyX# h.q.s.7 {.NXjXlXlXlXlXlXlXlXlXlXlXlXlXlXjXZX&.V 5.d tXcXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXnX7X4   ).BXjXlXlXlXlXlXlXjXVXs   X     X   %X<X).UXR.    .     X   k ZXhXlXlX",
"lXlXlXlXlXlXlXlXlXkXvXyX% d.N 5.q [.NXjXlXlXlXlXlXlXlXlXlXlXlXlXkXcXuX1 R.f.a aXcXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXtX6.3 8.NXjXlXlXlXlXlXlXjXVXs   X     X   XXbXW 8.UXK   X     X   k ZXhXlXlX",
"lXlXlXlXlXlXlXlXlXkXvXyX+ n.vXP.3 {.NXjXlXlXlXlXlXlXlXlXlXlXlXlXhXAXu.< OX+.q 1XvXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXfXxXIXu.2 5XbXjXlXlXlXlXlXjXVXs   X     X   >X~.  < iX2.  X     X   k ZXhXlXlX",
"lXlXlXlXlXlXlXlXlXkXvXiX* r.UXC.* %XmXjXlXlXlXlXlXlXlXlXlXlXlXlXgXDX>.# = $   d.MXjXlXlXlXlXlXlXlXlXlXlXlXlXjXmX1XD  XUXc.1 :XmXjXlXlXlXlXlXjXVXs   X     X   +X@X  9 CX@.  X     X   k ZXhXlXlX",
"lXlXlXlXlXlXlXlXlXlXkXbX@.. E ; A cXkXlXlXlXlXlXlXlXlXlXlXlXlXlXkXxXqX*X8X} < 3XvXkXlXlXlXlXlXlXlXlXlXlXlXlXkXxXaXc - / @ ) mXjXlXlXlXlXlXlXjXVXs   X     X   ] UX.X9XmX9   .     X   k ZXhXlXlX",
"lXlXlXlXlXlXlXlXlXlXkXcXaXq.J ;.qXvXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXvXmXSXJ.:.fXxXkXlXlXlXlXlXlXlXlXlXlXlXlXlXjXnX0X=.K 6.iXcXkXlXlXlXlXlXlXjXVXs   X           ] _.P.z   .       X   k ZXhXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXzXSXPXFXcXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXjXhXNXDXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXcXGXPXDXzXkXlXlXlXlXlXlXlXjXVXs   X         .         .         X   k ZXhXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXhXfXgXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXgXfXhXlXlXlXlXlXlXlXlXlXjXVXs   X           o + + X           X   k ZXhXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXVXs   X                             X   k ZXhXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXVXs   X                             X   k ZXhXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXVXs   X                             X   k ZXhXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXVXs   X                             X   k ZXhXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXVXs   X                             X   k ZXhXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXVXs   X                             X   k ZXhXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXVXs   X                             X   k ZXhXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXVXs   X                             X   k ZXhXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXkXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXkXkXlXlXlXlXlXlXlXlXlXjXVXs   X           . . . .           X   k ZXhXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXjXxXbXcXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXkXvXbXlXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXxXbXxXjXlXlXlXlXlXlXlXlXjXVXs   X                             X   k ZXhXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXbXjXwXdXmXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXxXbXyXtXvXcXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXnXfXeXgXnXkXlXlXlXlXlXlXlXjXVXs   X         % < < 1 < X         X   k ZXhXlXlX",
"lXlXlXlXlXlXlXlXlXlXjXnX Xp   8 K.MXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkX$.@ o o.gXxXkXlXlXlXlXlXlXlXlXlXlXlXlXlXjXMXW.9   a  XMXjXlXlXlXlXlXlXjXVXs   X     X   s.UXZXSXBX4   .     X   k ZXhXlXlX",
"lXlXlXlXlXlXlXlXlXkXzXkXx l .XY 2 yXxXkXlXlXlXlXlXlXlXlXlXlXlXlXjXVXH.  g.C.  D.VXjXlXlXlXlXlXlXlXlXlXlXlXlXkXxXaXp N .Xf V nXkXkXlXlXlXlXlXjXVXs   X     X   v.uXP F A +         X   k ZXhXlXlX",
"lXlXlXlXlXlXlXlXlXkXvXyXO M.UXW.,  XNXjXlXlXlXlXlXlXlXlXlXlXlXlXkXvX:X^.HXZX- i.CXjXlXlXlXlXlXlXlXlXlXlXlXlXkXxXsX!.7XUX*.y hXzXkXlXlXlXlXlXjXVXs   X     X   M.&X                X   k ZXhXlXlX",
"lXlXlXlXlXlXlXlXlXkXvXyX@ z.*XC.5 {.NXjXlXlXlXlXlXlXlXlXlXlXlXlXlXkXxXSX|.I 9 :XnXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXBXaX9., q.CXjXlXlXlXlXlXlXjXVXs   X     X   l.zXN.k.p   .       X   k ZXhXlXlX",
"lXlXlXlXlXlXlXlXlXkXvXyX% d.h 1.q [.NXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXAXi.  H hXxXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXxX5X< X (.BXjXlXlXlXlXlXlXjXVXs   X     X   h.UX1XkXpX>   .     X   k ZXhXlXlX",
"lXlXlXlXlXlXlXlXlXkXvXyX# k.G.c.6 {.NXjXlXlXlXlXlXlXlXlXlXlXlXlXlXkXmXnXnX#X& s.VXjXlXlXlXlXlXlXlXlXlXlXlXlXlXkXxXBXzXxXW g fXzXkXlXlXlXlXlXjXVXs   X     .   c /   y GX[   X     X   k ZXhXlXlX",
"lXlXlXlXlXlXlXlXlXkXvXyXO N.UX!., |.NXjXlXlXlXlXlXlXlXlXlXlXlXlXkXMX(.Y.SXFXI T MXkXlXlXlXlXlXlXlXlXlXlXlXlXkXvXwXb.uXUXU.< $XMXjXlXlXlXlXlXjXVXs   X         , @   ; aX<.  X     X   k ZXhXlXlX",
"lXlXlXlXlXlXlXlXlXkXzXjXl c +XE 1 tXxXkXlXlXlXlXlXlXlXlXlXlXlXlXhXSXe.  J.P.. u.BXjXlXlXlXlXlXlXlXlXlXlXlXlXjXnX5X& ' &XZ p sXxXkXlXlXlXlXlXjXVXs   X     X   k.ZXF 6.UXb   X     X   k ZXhXlXlX",
"lXlXlXlXlXlXlXlXlXlXjXnX}.t   5 G.MXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXaX_ o o / pXcXkXlXlXlXlXlXlXlXlXlXlXlXlXlXjXnXD.< X w ^.NXjXlXlXlXlXlXlXjXVXs   X     .   2 |.IXGXe.          X   k ZXhXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXnXfX8XpXmXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXcXcXwXqXcXcXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXnXpX8XdXmXkXlXlXlXlXlXlXlXjXVXs   X       .     2 >     .       X   k ZXhXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXjXxXnXcXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXlXbXnXlXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXcXnXcXjXlXlXlXlXlXlXlXlXjXVXd   X         .       . .         X   l ZXhXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXkXkXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXkXkXlXlXlXlXlXlXlXlXlXjXVXa   X             . .             X   j ZXhXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXBXP   O O O O O O O O O O O O O O O O   R CXhXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXkXlXlXlXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXkXkXnX{.,                                 2 .XnXkXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXbXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXmXlXlXxXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXcXkXkXMX*X@.Y R T T T T T T T T T T R Y $.-XMXkXlXlXlX",
"lXlXlXjXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXhXlXlXkXvX&X/.'.`.`.`.`.`.`.`.`.`.`.`.`.`.`.`._.{.kXcXtX/.'.`.`.`.`.`.`.`.`.`.`.`.`.`.`.`.'.^.9XvXkXkXbXDXJXHXHXHXHXHXHXHXHXHXHXHXHXJXDXbXkXlXlXlXlX",
"lXlXjXVXPXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXAXlXkXkXnX.XK.T.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.I.W.kXvXwXK.T.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.T.J.4XbXkXlXkXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXkXlXlXlXlXlX",
"lXhXVX!.+.1.,.,.,.,.,.,.,.,.,.,.,.,.,.,.,.,.C.zXcXkXlXvXmXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXlXlXzXmXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXmXxXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXfXPX;.                                      Q gXlXlXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXlXlXlXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXfXKX8.  & + + + + + + + + + + + + + + + + .   b.SXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXfXKX6.  +                 X @ X           @   :.KXfXlXlXlXlXlXlXlXlXlXlXgXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXgXfXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXgXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXfXKX6.  +               .       .         +   ,.KXfXlXlXlXlXlXlXlXlXlXlXHXFXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXxXGXPXSXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXkXGXFXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXfXKX6.  +             X   z ).I   .       +   ,.KXfXlXlXlXlXlXlXlXlXkXzX%.1.aXxXkXlXlXlXlXlXlXlXlXlXlXlXlXlXkXbXrX2.Y y.fXxXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXvXnX1.<.kXlXkXlXlXlXlXlXlXlXlXlXlX",
"lXfXKX6.  +             .   Q.UXq.  X       +   ,.KXfXlXlXlXlXlXlXlXhXCXE.  r rXvXkXlXlXlXlXlXlXlXlXlXlXlXlXkXzXhXS O Y   %.ZXhXlXlXlXlXlXlXlXlXlXlXlXlXlXkXlXfXX.  p fXzXkXlXlXlXlXlXlXlXlXlXlX",
"lXfXKX6.  +           .   h VXIX4.  X       +   ,.KXfXlXlXlXlXlXlXkXkXnX~   B tXcXkXlXlXlXlXlXlXlXlXlXlXlXlXkXbX7XU E.UX=.t uXcXkXlXlXlXlXlXlXlXlXlXlXlXlXkXmX@XR E b fXzXkXlXlXlXlXlXlXlXlXlXlX",
"lXfXKX6.  +           O   S.0X2Xu.  X       +   ,.KXfXlXlXlXlXlXlXjXBXXX< L x tXcXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXgXhXDX*.u aXxXkXlXlXlXlXlXlXlXlXlXlXlXlXlXzXgXAX1.f hXzXkXlXlXlXlXlXlXlXlXlXlX",
"lXfXKX6.  +         X   q lX=.>Xp.  X       +   ,.KXfXlXlXlXlXlXlXkXCX_ I 8.s rXcXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXmX4X% $.DXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXFX*.g hXzXkXlXlXlXlXlXlXlXlXlXlX",
"lXfXKX6.  +         o   w.2X  7X8.  o       +   ,.KXfXlXlXlXlXlXkXvX6X, XXj.d fXcXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXzXjXx i aXxXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXSX-.g hXzXkXlXlXlXlXlXlXlXlXlXlX",
"lXfXKX6.  +       .   $ dX!._ zXL..   .     +   ,.KXfXlXlXlXlXlXhXDX4.- G.~ 4 +XbXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXNX[ @ =XMXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXDX-.g hXzXkXlXlXlXlXlXlXlXlXlXlX",
"lXfXKX6.  +       .   > %XgXvXPXuX9   X     +   ,.KXfXlXlXlXlXlXhXAX0.7 5 ;   k.MXjXlXlXlXlXlXlXlXlXlXlXlXlXlXjXBXk.. ).PXvXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXSX:.l hXzXkXlXlXlXlXlXlXlXlXlXlX",
"lXfXKX6.  +           . = @ 6 bXx.  X       +   ,.KXfXlXlXlXlXlXlXzXdXtXbX#.2 wXvXkXlXlXlXlXlXlXlXlXlXlXlXlXjXmX<X    B p ) pXxXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXFX..7 hXzXkXlXlXlXlXlXlXlXlXlXlX",
"lXfXKX6.  +                 O =.A   .       +   ,.KXfXlXlXlXlXlXlXlXxXxXNX).l.fXxXkXlXlXlXlXlXlXlXlXlXlXlXlXkXvXwXi.5.<.=.g.dXzXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXMXQ.l.jXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXfXKX6.  +             . .       .         +   ,.KXfXlXlXlXlXlXlXlXlXkXjXBXFXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXcXHXKXLXPXGXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXVXFXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXfXKX6.  +                   + o           +   >.KXfXlXlXlXlXlXlXlXlXlXlXhXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXfXfXfXfXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXgXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXfXKX6.  +                                 @   3.JXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXfXKX6.  +                               .   $ }.MXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXfXKX4.  X                                 g K.MXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXkXxXyX2X5X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4XiXBXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXkXcXmXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXcXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX"
};

/* XPM */
static const char *const xpm_icon_2[] = {
/* columns rows colors chars-per-pixel */
"88 88 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXjXgXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXhXlXlXlXlXlXjXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXhXlXlXlXlXlX",
"lXlXlXlXlXjXmXHXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXAXlXkXlXlXjXBXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXVXkXlXlXlXlX",
"lXlXlXlXkXNXOX3.-.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.-.m.jXcXkXlXmX!.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.I.bXzXlXlXlX",
"lXlXlXjXNXI.%                                                                       ! hXjXmXi.                                                                        2.nXkXlXlX",
"lXlXlXkXbXx   @ + O + + O + @ + + + + + + + + + + + + + + + + + + O + @ + O + O + X   U.GX8X,   + + + + + + @ @ + + + + + + + + + + + + + + + + + O + @ + + + + + +   @ >XMXjXlX",
"lXlXlXlXcX7   .         X                                         .               +   M.IX,X  .         .       X                                 .                 o   +XBXjXlX",
"lXlXlXlXcX9   .       .   % 3                                   .   * 5 X         O   B.PX<X          .     8 :                                 .   . 6 X           X   @XBXjXlX",
"lXlXlXlXcX8   .     X   w zX,X    .                           . .   ].VX9   X     O   N.IX<X        .   2 @XDXmX*.  X                         .   # oXAX5   .       X   @XBXjXlX",
"lXlXlXlXcX8   .       @ {.xX@XX   .                           X   c UXjXw   X     O   N.IX<X        o   k.gX6 9.yX:   .                       X   m.hXiXq   .       X   @XBXjXlX",
"lXlXlXlXcX8   .       @ 0 6.<X    .                           o   K.gX7Xu   X     O   N.IX<X        O   ].H.  = 6 %                           .   e Y fX0   .       X   @XBXjXlX",
"lXlXlXlXcX8   .       o   9.<X    .                         X   p uXr.0Xp   X     O   N.IX<X        O   W.<X).FXX.  o                           O   F kX9   .       X   @XBXjXlX",
"lXlXlXlXcX8   .       O   9.<X    .                         o   x.J.f aX6   X     O   N.IX<X        O   Y.kXZ P.lX%   .                         o   H jX9   .       X   @XBXjXlX",
"lXlXlXlXcX8   .       o   9.<X    .                       .   - cXN.y.CXP   X     O   N.IX<X        O   '.Y.  B sXa   X                         o   G jX9   .       X   @XBXjXlX",
"lXlXlXlXcX8   .       o   7.>X    .                       .   1 '.1XiXUX5.  X     O   N.IX<X        o   Z.0X  5.cX>   .                         o   G gX9   .       X   @XBXjXlX",
"lXlXlXlXcX8   .       O   t.wX    .                                 P vXe   X     O   N.IX<X        .   u rXVXSX6.  X                           o   L VXq   .       X   @XBXjXlX",
"lXlXlXlXcX9   .       .   7 h                                   .   : z #         O   N.PX<X          .   > A d                                 .   ; c @           X   @XBXjXlX",
"lXlXlXlXcX9   .         .                                         .               O   B.PX<X            X       .                                 .                 X   @XBXjXlX",
"lXlXlXlXcX7   X           . X                                       . X           @   M.IX,X  X           . o X                                     . o             O   +XBXjXlX",
"lXlXlXkXmXJ   + O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O +     _.AXtXr   + O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O +   1 6XnXkXlX",
"lXlXlXjXmX#Xg                                                                     @ 8.bXgXMXU.6                                                                     , V.NXjXlXlX",
"lXlXlXlXjXMXtXY.J.K.K.K.K.K.K.K.K.K.K.K.K.K.K.K.K.K.K.K.K.K.K.K.K.K.K.K.K.K.K.K.J.OXMXzXlXkXBX3XL.J.K.K.K.K.K.K.K.K.K.K.K.K.K.K.K.K.K.J.H.H.H.H.H.H.H.H.H.H.H.H.H.H.:XBXkXlXlXlX",
"lXlXlXlXlXjXcXSXDXDXDXDXDXDXDXDXDXDXDXDXDXDXDXDXDXDXDXDXDXDXDXDXDXDXDXDXDXDXDXDXDXNXjXlXlXlXjXbXSXDXDXDXDXDXDXDXDXDXDXDXDXDXDXDXDXDXSXAXLXIXIXIXIXIXIXIXIXIXIXIXIXIXNXfXlXlXlXlX",
"lXlXlXlXlXlXkXhXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXjXlXlXlXlXlXjXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXkXcX<X&X*X*X*X*X*X*X*X*X*X*X*X*XiXNXjXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXhX*.&                           k `.MXjXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXZXa.    . . . . . . . . . . . . o   t rXvXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXjXgXgXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXgXgXkXlXlXlXlXlXlXlXgXGXU   O         X O + o           O   +XBXjXlX",
"lXlXlXlXlXlXlXlXlXlXlXkXNXKXJXnXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXCXGXxXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXCXKXGXcXkXlXlXlXlXlXlXgXGXY   O       .         .         X   @XBXjXlX",
"lXlXlXlXlXlXlXlXlXlXjXmXY.K ! OXmXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXBXg./ wXvXkXlXlXlXlXlXlXlXlXlXlXlXlXkXbXN.D  .6XbXkXlXlXlXlXlXgXGXY   O     X   j E.|./   .       X   @XBXjXlX",
"lXlXlXlXlXlXlXlXlXjXMX|.* ) F 7 rXcXkXlXlXlXlXlXlXlXlXlXlXlXlXkXbXwX% O <XnXjXlXlXlXlXlXlXlXlXlXlXlXjXBXH.  o.a G mXkXlXlXlXlXlXgXGXU   O   X   , rX&XA.UXP   X     X   @XBXjXlX",
"lXlXlXlXlXlXlXlXlXgXHX0.e UXrX1 Q.VXjXlXlXlXlXlXlXlXlXlXlXlXlXhXZXa.  a ,XnXjXlXlXlXlXlXlXlXlXlXlXlXkXmX_.V.UXL.< iXcXkXlXlXlXlXgXGXU   O   o   D GXX   ` S   .     X   @XBXjXlX",
"lXlXlXlXlXlXlXlXlXgXHX8.g 4X(.u I.VXjXlXlXlXlXlXlXlXlXlXlXlXlXzXfXj ( k ;XnXjXlXlXlXlXlXlXlXlXlXlXlXlXkXbXZXU.s X.BXjXlXlXlXlXlXgXGXU   O   o   G mX! K.E   .       X   @XBXjXlX",
"lXlXlXlXlXlXlXlXlXgXHX5.V  .' l P.VXjXlXlXlXlXlXlXlXlXlXlXlXhXDXv.x T.w ,XnXjXlXlXlXlXlXlXlXlXlXlXlXlXlXgXmX'   m.CXhXlXlXlXlXlXgXGXU   O   o   A IX~.+XUXn   X     X   @XBXjXlX",
"lXlXlXlXlXlXlXlXlXgXHX7.k @XI.p I.VXjXlXlXlXlXlXlXlXlXlXlXkXzXzXb s.{.8 ,XnXjXlXlXlXlXlXlXlXlXlXlXlXlXkXnXvXAXh.8 0XvXkXlXlXlXlXgXGXU   O   o   D HX8   9X8.  X     X   @XBXjXlX",
"lXlXlXlXlXlXlXlXlXgXHXw.q UXtX, !.BXjXlXlXlXlXlXlXlXlXlXlXkXnX7X1 4 5   0.NXjXlXlXlXlXlXlXlXlXlXlXlXjXVXz.c.UX%X1 XXNXjXlXlXlXlXgXGXU   O   o   S FX=   8X9.  X     X   @XBXjXlX",
"lXlXlXlXlXlXlXlXlXjXMXoX; U M w yXxXkXlXlXlXlXlXlXlXlXlXlXlXzXgX{.}.q.o _.MXjXlXlXlXlXlXlXlXlXlXlXlXjXCXj.  o.p N lXlXkXlXlXlXlXgXGXU   O   .   : qX,XE.GXx   X     X   @XBXjXlX",
"lXlXlXlXlXlXlXlXlXlXjXmX^.Q [ &XnXkXlXlXlXlXlXlXlXlXlXlXlXlXlXzXNXHX:X;.tXvXkXlXlXlXlXlXlXlXlXlXlXlXlXkXnXN.U #.5XnXkXlXlXlXlXlXgXGXU   O     X   a G.~.K   .       X   @XBXjXlX",
"lXlXlXlXlXlXlXlXlXlXlXkXNXLXJXnXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXgXcXFXzXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXZXLXHXcXkXlXlXlXlXlXlXgXGXU   O       .         .         X   @XBXjXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXjXgXgXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXgXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXgXgXkXlXlXlXlXlXlXlXgXGXU   O         . O + X           X   @XBXjXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXGXU   O                           X   @XBXjXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXGXU   O                           X   @XBXjXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXGXU   O                           X   @XBXjXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXGXU   O                           X   @XBXjXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXGXU   O                           X   @XBXjXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXGXU   O                           X   @XBXjXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXGXU   O                           X   @XBXjXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXkXhXhXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXhXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXhXjXlXlXlXlXlXlXlXlXgXGXU   O         o o o o .         X   @XBXjXlX",
"lXlXlXlXlXlXlXlXlXlXlXkXxXAXZXlXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXBXSXbXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXvXSXVXkXlXlXlXlXlXlXlXgXGXU   O                   .       X   @XBXjXlX",
"lXlXlXlXlXlXlXlXlXlXkXbXiX!._.kXcXkXlXlXlXlXlXlXlXlXlXlXlXlXlXzXnX@XY.6XmXkXlXlXlXlXlXlXlXlXlXlXlXlXlXkXmXwXR..XvXlXlXlXlXlXlXlXgXGXU   O   .   % C Y Y R *   .     X   @XBXjXlX",
"lXlXlXlXlXlXlXlXlXkXxXrXN = * ) cXlXlXlXlXlXlXlXlXlXlXlXlXlXjXMXy.o , q %XMXjXlXlXlXlXlXlXlXlXlXlXlXkXbX=X8 > $ w.VXjXlXlXlXlXlXgXGXU   O   X   i SXNXyXfXt   X     X   @XBXjXlX",
"lXlXlXlXlXlXlXlXlXhXDXj.; aX].@  XMXjXlXlXlXlXlXlXlXlXlXlXkXzXjX! a.GXi ;.AXhXlXlXlXlXlXlXlXlXlXlXlXjXVXm.J MXg.4 sXxXkXlXlXlXlXgXGXU   O   X   y sXC   o .         X   @XBXjXlX",
"lXlXlXlXlXlXlXlXlXgXJX7.d GX3Xt I.VXjXlXlXlXlXlXlXlXlXlXlXlXlXkXfXcXeXe s.ZXhXlXlXlXlXlXlXlXlXlXlXlXlXlXfXjXNX;.k zXlXkXlXlXlXlXgXGXU   O   X   u dX! -     .       X   @XBXjXlX",
"lXlXlXlXlXlXlXlXlXgXHX6.m t.2.g I.VXjXlXlXlXlXlXlXlXlXlXlXlXlXjXMX-X  t pXvXkXlXlXlXlXlXlXlXlXlXlXlXlXlXhXVXI   J.ZXhXlXlXlXlXlXgXGXU   O   X   u VXKXZXT.O   .     X   @XBXjXlX",
"lXlXlXlXlXlXlXlXlXgXHX6.n i.5.h I.VXjXlXlXlXlXlXlXlXlXlXlXlXlXlXBXsXG.8 m.VXjXlXlXlXlXlXlXlXlXlXlXlXlXkXnXnX%XI H lXlXkXlXlXlXlXgXGXU   O   .   2 V.^ b JX(   X     X   @XBXjXlX",
"lXlXlXlXlXlXlXlXlXgXJX7.a UXrXq U.VXjXlXlXlXlXlXlXlXlXlXlXlXxXfX].kXUX$.A mXkXlXlXlXlXlXlXlXlXlXlXlXkXbX#X>XUX&X1 XXNXjXlXlXlXlXgXGXU   O       o       *Xt.  X     X   @XBXjXlX",
"lXlXlXlXlXlXlXlXlXhXAXA.# (.z.+ =XnXkXlXlXlXlXlXlXlXlXlXlXkXcXiXq :.<Xi o.VXjXlXlXlXlXlXlXlXlXlXlXlXhXDX-.y :X2.4 9XvXkXlXlXlXlXgXGXU   O   X   q yX*.S PXW   X     X   @XBXjXlX",
"lXlXlXlXlXlXlXlXlXlXlXkXo.% > y.mXkXlXlXlXlXlXlXlXlXlXlXlXlXjXmXG.5 * V 5XbXjXlXlXlXlXlXlXlXlXlXlXlXkXcX8XS & 4 C.BXjXlXlXlXlXlXgXGXU   O     .   6.NXAXV..   .     X   @XBXjXlX",
"lXlXlXlXlXlXlXlXlXlXlXxXbXtXiXmXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXdXwXxXbXkXlXlXlXlXlXlXlXlXlXlXlXlXlXkXbXcXwXsXMXkXlXlXlXlXlXlXgXGXY   O           & :     .       X   @XBXjXlX",
"lXlXlXlXlXlXlXlXlXlXlXkXkXvXvXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXxXbXlXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXlXbXcXjXlXlXlXlXlXlXlXgXGXY   O         X     . .         X   @XBXjXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXkXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXkXlXlXlXlXlXlXlXlXgXGXU   O           . .             O   +XBXjXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXlXlXlXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXhXCXs.    X . . . . . . . . . . . o   y rXvXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXxXbXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXbXxXlXzXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXbXcXkXzXhX-.*                           l '.MXjXlXlX",
"lXlXlXkXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXhXkXlXlXxXpX9X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X9XdXxXjX0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X9XrXzXkXcXmX4X;X:X;X;X;X;X;X;X;X;X;X;X;XaXNXjXlXlXlX",
"lXlXkXcXDXDXDXDXDXDXDXDXDXDXDXDXDXDXDXDXSXvXjXkXmX@Xb.Z.C.C.C.C.C.C.C.C.C.C.C.C.C.Z.b.,XMXiXV.C.C.C.C.C.C.C.C.C.C.C.C.C.C.Z.m.W.bXkXkXjXnXMXMXMXMXMXMXMXMXMXMXMXMXMXxXjXlXlXlXlX",
"lXkXcXyXG.K.K.K.K.K.K.K.K.K.K.K.K.K.K.J.I.qXNXjXzXjXfXgXfXfXfXfXfXfXfXfXfXfXfXfXfXgXfXjXlXkXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXgXfXgXlXlXlXlXkXjXjXjXjXjXjXjXjXjXjXjXjXjXkXlXlXlXlXlX",
"lXjXVXoX                                  u }.MXjXzXxXzXxXxXxXxXxXxXxXxXxXxXxXxXxXzXxXzXlXlXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXjXBX#X  @ O O O O O O O O O O O O O O +   M xXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXjXBX@X  X               . X .         .   : gXxXlXlXlXlXlXlXlXlXlXkXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXjXkXjXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXkXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXjXBX@X  X                             .   , gXzXlXlXlXlXlXlXlXlXlXnXmXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXxXVXNXBXnXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXBXmXzXlXlXlXlXlXlXlXlXlXlXlX",
"lXjXBX@X  X           .   4 rXs.  .     .   , gXzXlXlXlXlXlXlXlXjXNX&.h 7XbXjXlXlXlXlXlXlXlXlXlXlXlXlXzXgX%.7 n .XmXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXBX;.d 0XcXkXlXlXlXlXlXlXlXlXlX",
"lXjXBX@X  X           O   0.UXS.  X     .   , gXzXlXlXlXlXlXlXjXmX<X  ; 1XnXjXlXlXlXlXlXlXlXlXlXlXlXhXZXi.@ S.G g xXlXkXlXlXlXlXlXlXlXlXlXlXlXjXmX5.o 2 2XvXkXlXlXlXlXlXlXlXlXlX",
"lXjXBX@X  X         X   : 7XNXC.  .     .   , gXzXlXlXlXlXlXlXhXAX,.* d >XnXjXlXlXlXlXlXlXlXlXlXlXlXkXnX]._.UXW.7 4XbXjXlXlXlXlXlXlXlXlXlXlXlXkXcXQ.n.e 3XbXkXlXlXlXlXlXlXlXlXlX",
"lXjXBX@X  X         o   *.2XU.U.  .     .   , gXzXlXlXlXlXlXkXvXqXp $.h -XnXjXlXlXlXlXlXlXlXlXlXlXlXlXkXmXcXSXo.s bXlXkXlXlXlXlXlXlXlXlXlXlXlXlXhXLX_.5 3XbXkXlXlXlXlXlXlXlXlXlX",
"lXjXBX@X  X             8X' n.Y.  X     .   , gXzXlXlXlXlXlXgXFXr.G ].w 2XnXjXlXlXlXlXlXlXlXlXlXlXlXlXlXfXCXT.  U.VXjXlXlXlXlXlXlXlXlXlXlXlXlXlXhXBX~.6 3XbXkXlXlXlXlXlXlXlXlXlX",
"lXjXBX@X  X       o   ^ cXl /.`.        .   , gXzXlXlXlXlXkXxXfXu w.F.3 OXmXjXlXlXlXlXlXlXlXlXlXlXlXlXjXNX:X# 3.ZXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXCX^.6 3XbXkXlXlXlXlXlXlXlXlXlX",
"lXjXBX@X  X       O   &.NXhXFXnXg   X   .   , gXzXlXlXlXlXkXbX8Xp 5 <   8.NXjXlXlXlXlXlXlXlXlXlXlXlXkXxXdXj ] UXVXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXCX/.0 4XbXkXlXlXlXlXlXlXlXlXlX",
"lXjXBX@X  X           % 8 - oX.X  .     .   , gXzXlXlXlXlXlXlXjX7XuXM.# @XmXjXlXlXlXlXlXlXlXlXlXlXlXhXAX,.  n N / yXxXkXlXlXlXlXlXlXlXlXlXlXlXlXhXZXE.@ 1XbXkXlXlXlXlXlXlXlXlXlX",
"lXjXBX@X  X                 L L   .     .   , gXzXlXlXlXlXlXlXlXvXVX5Xm.iXcXkXlXlXlXlXlXlXlXlXlXlXlXkXnX).i.r.6.k.aXzXkXlXlXlXlXlXlXlXlXlXlXlXlXkXbX3Xc.uXxXlXlXlXlXlXlXlXlXlXlX",
"lXjXBX@X  X           . X X     .       .   , gXzXlXlXlXlXlXlXlXkXjXvXDXxXkXlXlXlXlXlXlXlXlXlXlXlXlXlXkXVXJXJXLXGXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXbXFXxXlXlXlXlXlXlXlXlXlXlXlX",
"lXjXBX@X  X                 o o         .   : gXxXlXlXlXlXlXlXlXlXlXkXgXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXfXgXfXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXgXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXjXBX#X  # + + + + + + + + + + + + O + +   a lXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXjXVXoX                                  @ S.NXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXkXbX6X%.:.;.;.;.;.;.;.;.;.;.;.;.;.;.-.2. XNXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXkXvXKXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXHXMXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXkXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXgXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX"
};

/* XPM */
static const char *const xpm_icon_3[] = {
/* columns rows colors chars-per-pixel */
"64 64 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXkXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXhXlXlXlXhXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXkXlXlXlXlX",
"lXlXlXlXkXbXFXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXHXCXkXlXlXZXHXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXHXFXcXkXlXlXlX",
"lXlXlXjXnX2X2.$.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.#.K.bXlXxXB.@.*.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.*.#.9.wXbXkXlXlX",
"lXlXkXxXsXg                                                   Z.UXp.                                                  D cXlXlXlX",
"lXlXjXMX;X  O O O @     + O O O O O O O O O O O @     @ O %   X.UXL   $ O @       + O O O O O O O O O O +     + O +   % rXvXkXlX",
"lXlXjXMX>X      X   A ^   .                   X   ( B   . O   #.UXT   o X   m j.M   X                     X.g   . .   ; tXvXkXlX",
"lXlXjXMX:X    X   e hX_.  o                 .   < UXt.  O O   @.UXY   +   q :X4.[.3   .             o   [ UX|   o .   - tXvXkXlX",
"lXlXjXMX:X    .   o } G.  X                 O   6.cX-.  o O   @.UXY   @   G '.d A X                 .   * B.X.  o .   - tXvXkXlX",
"lXlXjXMX:X      o   K T.  X               .   2 C.e.4.  O O   @.UXY   @   m qXK.:X%   .               O   b.@.  o .   - tXvXkXlX",
"lXlXjXMX:X      X   U P.  X               O   O.3X'.K.  X O   @.UXY   @   G {.  oXn   X               o   b.O.  o .   - tXvXkXlX",
"lXlXjXMX:X      o   Q ).  X               .   i ' #XU.  X O   @.UXY   +   4 %XU.+X*   .               O   F.=.  o .   - tXvXkXlX",
"lXlXjXMX>X      .   6 M   .                 .     q i   . O   #.UXT   o X   u =.q   X                 .   x r   . .   ; tXvXkXlX",
"lXlXjXMX-X  X X X o     o X X X X X X X X X . o #     o . @   o.UXP   + . o       o . X X X X X X X X . o     o X X   = rXvXkXlX",
"lXlXkXbX9X&                                                   0.UXX.                                                  0 fXxXkXlX",
"lXlXlXjXmXF.s w e e e e e e e e e e e e e e e e e e e e e 0 | uXnX8XQ 0 r e e e e e e e e e e e q 9 9 9 9 9 9 9 0 8 h ~.MXjXlXlX",
"lXlXlXlXkXNXvXlXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXlXBXvXjXbXNXlXzXzXzXzXzXzXzXzXzXzXzXkXnXDXDXDXDXDXDXDXDXDXGXMXkXlXlXlX",
"lXlXlXlXlXjXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXkXlXkXjXlXlXlXlXlXlXlXlXlXlXlXkXMX4XD.D.D.D.D.D.D.F.A.W.kXxXkXlXlX",
"lXlXlXlXlXlXlXlXlXlXjXjXlXlXlXlXlXlXlXlXlXlXlXlXlXjXjXlXlXlXlXlXlXlXlXlXlXlXkXhXkXlXlXlXlXjXnX*X5                     O.nXkXlXlX",
"lXlXlXlXlXlXlXlXlXkXVXCXkXlXlXlXlXlXlXlXlXlXlXlXkXMXnXkXlXlXlXlXlXlXlXlXlXkXvXSXcXkXlXlXlXgXGXi.  $ o O X     + o +   & yXcXkXlX",
"lXlXlXlXlXlXlXlXlXnX{.'.bXlXlXlXlXlXlXlXlXlXlXkXbX=X2XvXkXlXlXlXlXlXlXlXkXbXwXI.rXbXkXlXlXgXGXi.  O .   + T y   . .   ; tXvXkXlX",
"lXlXlXlXlXlXlXhXCXN.N M z.ZXhXlXlXlXlXlXlXlXkXxXgX= 8.DXhXlXlXlXlXlXlXkXxXpXG K T fXzXkXlXgXGXi.  + .   G.`.=Xz   o   - tXvXkXlX",
"lXlXlXlXlXlXlXhXGXR (.|.R CXjXlXlXlXlXlXlXlXhXSXM.O h.ZXhXlXlXlXlXlXlXlXcXtXXXtXM 8XbXkXlXgXGXi.  +   , ;X, V 0   X   - tXvXkXlX",
"lXlXlXlXlXlXlXhXSX+.o.| @.mXjXlXlXlXlXlXlXlXzXgXX.#.p.DXhXlXlXlXlXlXlXlXkXcXHXB W AXhXlXlXgXGXi.  +   - <X/.>X4   X   - tXvXkXlX",
"lXlXlXlXlXlXlXhXFX( D.J.) NXjXlXlXlXlXlXlXhXSXA.A +.#.CXjXlXlXlXlXlXlXlXxXaXaXcXH #XMXjXlXgXGXi.  +   > 3X  Z.&.  O   - tXvXkXlX",
"lXlXlXlXlXlXlXhXFX:.O.$.$.SXhXlXlXlXlXlXlXjXNX].=.u U NXjXlXlXlXlXlXlXkXmX>XF N.b ;XmXkXlXgXGXi.  +   X #X,.$XJ   o   - tXvXkXlX",
"lXlXlXlXlXlXlXkXxXpX1.>.tXcXkXlXlXlXlXlXlXlXkXvXUX'.^.BXjXlXlXlXlXlXlXlXkXbXJ.' E.NXjXlXlXgXGXi.  O X   j G.o.  . .   - tXvXkXlX",
"lXlXlXlXlXlXlXlXlXxXGXHXcXkXlXlXlXlXlXlXlXlXlXkXfXmXMXjXlXlXlXlXlXlXlXlXlXkXCXKXBXkXlXlXlXgXGXi.  O   .           .   - tXvXkXlX",
"lXlXlXlXlXlXlXlXlXkXgXgXkXlXlXlXlXlXlXlXlXlXlXlXlXjXjXlXlXlXlXlXlXlXlXlXlXlXjXgXjXlXlXlXlXgXGXi.  O     X + o     .   - tXvXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXGXi.  O               .   - tXvXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXGXi.  O               .   - tXvXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXGXi.  O               .   - tXvXkXlX",
"lXlXlXlXlXlXlXlXlXlXkXkXlXlXlXlXlXlXlXlXlXlXlXlXkXkXlXlXlXlXlXlXlXlXlXlXlXlXlXkXlXlXlXlXlXgXGXi.  O     . . .     .   - tXvXkXlX",
"lXlXlXlXlXlXlXlXlXjXcXvXjXlXlXlXlXlXlXlXlXlXlXkXzXbXkXlXlXlXlXlXlXlXlXlXlXkXlXbXkXkXlXlXlXgXGXi.  O               .   - tXvXkXlX",
"lXlXlXlXlXlXlXlXkXmXyXtXMXkXlXlXlXlXlXlXlXlXkXnXjX9XmXlXlXlXlXlXlXlXlXlXkXcXbX7XcXxXkXlXlXgXGXi.  O     = 8 8 o   .   - tXvXkXlX",
"lXlXlXlXlXlXlXjXNX_.n v W.BXjXlXlXlXlXlXlXkXbX4XA l h.BXjXlXlXlXlXlXlXlXzXjX_ g &.xXlXlXlXgXGXi.  +     }.=X/.5   X   - tXvXkXlX",
"lXlXlXlXlXlXlXgXHXQ L.W.E AXjXlXlXlXlXlXlXkXmX+XT.+Xm bXkXlXlXlXlXlXlXkXvXqXm.iXz 3XnXkXlXgXGXi.  +   O {.w     . .   - tXvXkXlX",
"lXlXlXlXlXlXlXhXSX..4.3.X.MXjXlXlXlXlXlXlXlXjXNXlXy t.DXhXlXlXlXlXlXlXlXkXzXHXY W CXjXlXlXgXGXi.  +     2X7Xk.o   .   - tXvXkXlX",
"lXlXlXlXlXlXlXhXDX{ a.a.} MXjXlXlXlXlXlXlXlXlXkXBXC./ lXlXlXlXlXlXlXlXlXlXjXNX.XK 4XbXkXlXgXGXi.  O   . U w '.(   O   - tXvXkXlX",
"lXlXlXlXlXlXlXhXGX[ s.l.) SXhXlXlXlXlXlXlXjXZXI.5.XXx aXxXkXlXlXlXlXlXkXmX;X..2Xv XXNXjXlXgXGXi.  +     <.s `./   O   - tXvXkXlX",
"lXlXlXlXlXlXlXkXbX<XT P *XmXjXlXlXlXlXlXlXkXcXwX{ V I.NXjXlXlXlXlXlXlXlXlXlX5.n a.nXkXlXlXgXGXi.  O X   +.;Xl..   .   - tXvXkXlX",
"lXlXlXlXlXlXlXlXkXbXVXVXnXkXlXlXlXlXlXlXlXlXkXvXZXNXNXkXlXlXlXlXlXlXlXlXlXzXZXNXVXlXlXlXlXgXGXi.  O               .   ; tXvXkXlX",
"lXlXlXlXlXlXlXlXlXkXjXjXkXlXlXlXlXlXlXkXkXkXkXjXhXjXhXkXkXkXkXlXlXkXkXkXkXkXhXjXhXkXkXkXkXfXGXi.  $ O o @ + @ O o +   & yXcXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXvXbXbXbXbXbXbXbXbXbXbXbXcXkXcXbXbXbXbXbXbXbXbXbXbXbXxXnX=X6                     +.nXkXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXlXlX8X5X6X5X5X5X5X5X5X5X6X4XtXcXwX4X6X5X5X5X5X5X5X5X6X4XqXkXMX5XD.D.D.D.D.D.D.F.A.!.zXxXkXlXlX",
"lXlXlXlXzXzXzXzXzXzXzXzXzXzXlXxXBXzXlX}./.).).).).).).).)._.~.;XMX$X~._.).).).).).).)._.^.oXcXjXbXSXSXSXSXSXSXSXSXDXCXlXkXlXlXlX",
"lXkXcXuXg 0 r e e e e e e e e e q.cXkXbXnXnXnXnXnXnXnXnXnXnXmXcXkXvXnXnXnXnXnXnXnXnXnXnXnXbXlXlXkXhXhXhXhXhXhXhXhXhXhXlXlXlXlXlX",
"lXkXvXtX@                         ^.CXgXkXkXkXkXkXhXjXkXkXkXkXkXlXkXkXkXkXkXhXhXhXkXkXkXkXkXlXlXlXlXlXlXkXhXkXlXlXlXlXlXlXlXlXlX",
"lXkXvXtX:   o X X X       X . @   Z.DXhXlXlXlXlXlXBXbXkXlXlXlXlXlXlXlXlXlXzXZXNXBXlXlXlXlXlXlXlXlXlXlXkXbXAXcXlXlXlXlXlXlXlXlXlX",
"lXkXvXtX-   .   .   - |.b   X O   F.SXhXlXlXlXkXMX' n.ZXjXlXlXlXlXlXlXlXlXxX8.b h.MXjXlXlXlXlXlXlXlXkXcX9XJ W.VXjXlXlXlXlXlXlXlX",
"lXkXvXtX-   .   O   $.UXD   o O   D.SXhXlXlXjXBXOX  t.SXhXlXlXlXlXlXlXkXnX3Xo. Xc <XnXkXlXlXlXlXlXlXjXNXA.5 V.AXhXlXlXlXlXlXlXlX",
"lXkXvXtX-   . .   + ^.$XL   o O   D.SXhXlXlXhXZX*.b f.AXhXlXlXlXlXlXlXlXlXhXDXtXc wXvXkXlXlXlXlXlXlXlXgXGX>.v.DXhXlXlXlXlXlXlXlX",
"lXkXvXtX-   . o   +.s.x.Q   o O   D.SXhXlXjXNX.X{ i.0.DXhXlXlXlXlXlXlXlXkXzXMXD f.SXhXlXlXlXlXlXlXlXlXhXFX#.v.DXhXlXlXlXlXlXlXlX",
"lXkXvXtX-   . o   x.-XvXt.  o O   D.SXhXlXhXSXN.j u U mXkXlXlXlXlXlXlXlXjXVX$. .GXjXlXlXlXlXlXlXlXlXlXhXFX+.x.DXhXlXlXlXlXlXlXlX",
"lXkXvXtX-   .     - 3 W.^   o O   D.SXhXlXlXzXaXuX,.6.AXjXlXlXlXlXlXlXkXnX1X3 G ` wXcXkXlXlXlXlXlXlXlXhXDX:.N.SXhXlXlXlXlXlXlXlX",
"lXkXvXtX-   .         @ X     O   F.SXhXlXlXlXzXmXjXgXzXlXlXlXlXlXlXlXlXzXhXyX5X5XjXlXlXlXlXlXlXlXlXlXlXzXsXfXzXlXlXlXlXlXlXlXlX",
"lXkXvXtX, . + O O + @ X o O O $   Z.DXgXlXlXlXlXjXzXzXlXlXlXlXlXlXlXlXlXlXzXvXnXnXzXlXlXlXlXlXlXlXlXlXlXlXxXzXlXlXlXlXlXlXlXlXlX",
"lXkXvXrX                        & *XmXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXkXkXlXlXlXlXlXlXlXlXlXlXlXlXkXlXlXlXlXlXlXlXlXlXlX",
"lXkXxXsX,.$.&.&.&.&.&.&.&.&.&.=. XMXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXzXFXHXGXGXGXGXGXGXGXGXGXGXMXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXgXgXgXgXgXgXgXgXgXgXgXgXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX"
};

/* XPM */
static const char *const xpm_icon_4[] = {
/* columns rows colors chars-per-pixel */
"48 48 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXjXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXkXlXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXlXlXlXlX",
"lXlXlXkXmXmXzXxXzXzXzXzXzXzXzXzXzXzXzXzXxXzXmXnXzXBXzXxXzXzXzXzXzXzXzXzXzXzXzXzXxXzXcXNXlXlXlXlX",
"lXlXjXmX$Xb y p s p u i i i i i i i p s p t n =XcX{ w p a s p i i i i i i i p s i i t n.NXjXlXlX",
"lXlXgXGX*.                                    0.>X                                    e cXlXlXlX",
"lXlXgXFX=.  @   q.C   O X X X X o   3 p.+ +   q.;X  O   X.k.0   o X X X o   c u.  O   p zXlXlXlX",
"lXlXgXFX=.  o . I.]   o         O   &.uXX X   q.;X    8 L.O.d   .       X   K `.X .   i xXlXlXlX",
"lXlXgXFX*.  $   ^ `   o       .   : N.c.; .   q.;X    q L.k.S   X             d.$     i zXlXlXlX",
"lXlXgXFX=.  #   &...  o       X   i I.3Xw     q.;X    7 n.t.X.  o           % S.#     i xXlXlXlX",
"lXlXgXFX=.  @   l h   X . . . . .   . R $ o   q.;X  O   R 4.@   . . . . .   O I O X   p zXlXlXlX",
"lXlXgXGX#.  X                             X   7.-X                                    q xXlXlXlX",
"lXlXjXNX(.2 % & * * & & & & & & & & & = * $ 3 {.jXV O * - ; & & & & & # # # # % # $ X 5.NXjXlXlX",
"lXlXlXkXmXpX7X9X9X9X9X9X9X9X9X9X9X9X9X9X9X7XaXnXcXlX7X9X9X9X9X9X9X9X8XaXfXdXfXfXfXdXjXSXlXlXlXlX",
"lXlXlXlXjXxXbXbXxXcXbXbXbXbXbXbXbXbXvXxXbXbXxXkXkXlXbXbXcXxXbXbXbXvXVXD.U W Q ~ Q E R !.mXjXlXlX",
"lXlXlXlXlXkXjXlXSXBXjXkXkXkXkXkXkXjXlXCXkXkXkXlXlXlXkXjXVXAXlXjXjXcXeX#               a bXkXlXlX",
"lXlXlXlXlXlXzXgXg.Y.nXkXlXlXlXlXlXxXpXV.hXzXlXlXlXlXkXbXP.j.dXxXjXbX8X& X   b w.t     u zXlXlXlX",
"lXlXlXlXlXhXSXS.1.#.4XbXkXlXlXlXhXDXV.8 jXzXkXlXlXlXzXsXV. .Y.AXgXbX9X*   . C.2.F     i xXlXlXlX",
"lXlXlXlXlXhXSXV.7.*.:XmXkXlXlXlXzXfX;.$.pXcXlXlXlXlXkXcXFX( +XNXhXbX9X&   + H.x.I     i zXlXlXlX",
"lXlXlXlXlXhXDXM.8.#.,XnXkXlXlXjXMX&XU b 1XnXkXlXlXlXxXyX^.u.c.DXgXbX9X&   + B.%.s.    i zXlXlXlX",
"lXlXlXlXlXkXvXeX>.z.vXkXlXlXlXlXlXkX9Xf.uXcXkXlXlXlXlXxXd.;.8XvXjXbX9X&     E C.u     i zXlXlXlX",
"lXlXlXlXlXlXkXcXCXBXlXlXlXlXlXlXlXlXbXVXzXlXlXlXlXlXlXzXCXVXvXkXkXbX9X&   .       o   i zXlXlXlX",
"lXlXlXlXlXlXlXkXhXjXlXlXlXlXlXlXlXlXkXjXlXlXlXlXlXlXlXlXjXhXkXlXkXbX9X&   . X o . X   i zXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXbX9X&   .       X   i zXlXlXlX",
"lXlXlXlXlXlXlXlXhXjXlXlXlXlXlXlXlXlXjXjXlXlXlXlXlXlXlXlXjXhXlXlXkXbX9X&   . X O . X   i zXlXlXlX",
"lXlXlXlXlXlXlXlXAXNXkXlXlXlXlXlXlXkXCXVXkXlXlXlXlXlXlXkXNXAXlXlXkXbX9X&   .       o   i zXlXlXlX",
"lXlXlXlXlXlXlXcXU.OXmXkXlXlXlXlXlXcX^._.bXkXlXlXlXlXkXbX.XY.zXlXkXbX9X&     M O.e     i zXlXlXlX",
"lXlXlXlXlXhXZXY.#.@.0XvXkXlXlXkXvX8Xq.' *XMXkXlXlXlXzXfXs.[ W.ZXgXbX9X&     I.+.<     i zXlXlXlX",
"lXlXlXlXlXhXSXN.q.=.:XmXkXlXlXlXjXMXuXR wXvXkXlXlXlXkXxXNX^ OXNXhXbX9X&     V.c.r     i zXlXlXlX",
"lXlXlXlXlXhXDXn.w.%.:XmXkXlXlXkXvX9X-X>.(.CXjXlXlXlXxXiX-Xi.m.SXgXbX9X&   X c #.d.    i zXlXlXlX",
"lXlXlXlXlXkXnX<X..q.kXlXlXlXlXkXvXeX%.=.0XvXkXlXlXlXzXjX6...*XmXhXbX9X*      .I.n     p xXlXlXlX",
"lXlXlXlXlXlXkXbXlXvXxXlXlXlXlXkXjXcXxXlXvXjXkXkXlXkXjXzXvXjXbXjXjXbX7X@ . O   +   #   e zXlXlXlX",
"lXlXlXkXgXhXhXfXhXgXgXhXjXlXxXnXnXbXnXnXbXnXnXcXzXnXnXbXbXnXbXnXbXnXdXu               K MXjXlXlX",
"lXlXkXcXDXSXSXSXSXSXSXDXNXzXuX:X<X<X,X,X<X<X:XrXgX>X<X<X,X,X<X<X>X7XmX,Xv.n.n.n.n.b.M.wXvXkXlXlX",
"lXkXvXwXN.C.C.V.C.Z.C.m.[.mXyX;X>X>X>X:X>X>X-XrXgX;X>X>X:X;X>X>X;X7XzXbXFXDXDXSXDXDXDXcXkXlXlXlX",
"lXjXVX{.                  '.CXvXnXnXnXCXnXnXmXcXzXnXnXbXVXSXbXnXnXvXlXkXgXgXhXxXgXgXgXkXlXlXlXlX",
"lXjXBX.X  + O o # 0 X $   m.DXfXkXkXlX4XhXkXkXkXlXkXjXcX5X#XbXjXkXkXlXlXlXzXkX3XlXlXlXlXlXlXlXlX",
"lXjXBX X  . O   &.XX  @   C.SXhXjXCX`.d jXzXkXlXlXlXzXfX2.` `.VXjXlXlXlXjXVXD.S xXlXlXlXlXlXlXlX",
"lXjXBX X  .     D.m.  +   V.SXhXjXBX9.W gXxXlXlXlXlXzXsXSXw.H.AXjXlXlXlXkXcX0X%.dXxXlXlXlXlXlXlX",
"lXjXBX X  O   L |.S.O o   V.SXfXMX=XI ! 6XbXkXlXlXlXjXCX!.2.CXjXlXlXlXlXlXzXhX%.sXxXlXlXlXlXlXlX",
"lXjXBX X  X   4 &.I.. o   C.SXgXcXtXG.E 8XbXkXlXlXlXzXjXZ @.1XbXkXlXlXlXlXxXdX,.dXxXlXlXlXlXlXlX",
"lXjXBX.X  + +     # X $   N.DXhXkXcXAXjXzXlXlXlXlXlXlXjXwX>XiXxXlXlXlXlXlXlXlXpXlXlXlXlXlXlXlXlX",
"lXjXVX{.                  T.ZXhXlXkXhXzXlXlXlXlXlXlXlXlXvXmXxXlXlXlXlXlXlXlXlXxXlXlXlXlXlXlXlXlX",
"lXkXnX3X$.=.=.*.*.=.=.#.v.zXlXlXlXlXlXkXlXlXlXlXlXlXlXlXkXkXlXlXlXlXlXlXlXlXlXkXlXlXlXlXlXlXlXlX",
"lXlXkXcXGXFXFXFXFXFXFXGXAXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXkXgXgXgXgXgXgXgXgXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX"
};

/* XPM */
static const char *const xpm_icon_5[] = {
/* columns rows colors chars-per-pixel */
"44 44 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXkXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXjXlXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXlXlXlXlX",
"lXlXlXkXvXAXCXZXZXZXZXZXZXZXZXZXZXZXZXCXAXMXlXZXZXZXZXZXZXZXZXZXZXZXZXZXZXCXZXCXlXlXlXlX",
"lXlXkXvX9X' F L P J J J J J J J J L L J K '.NX7.A P L L J J J J J J J P L K A l.nXkXlXlX",
"lXlXgXFXg.                                T 7X                                $ yXcXkXlX",
"lXlXgXFXs.  X 0 x.=   O o o o @   } ..    W 2X    4 p. .  O o o o O   5.E   X > eXvXkXlX",
"lXlXgXFXd.    1 J.2   .           '.2.    E 3X    Y H.~   .       .   5.+.    : rXvXkXlX",
"lXlXgXFXd.  #   0.7   .     o   L .X*.    E 3X    ! j.a.#         o   S ..    : eXvXkXlX",
"lXlXgXFXf.  +   8.4   .     X   q g.0.    W 3X    s N.8.          X   J ]     > rXvXkXlX",
"lXlXgXGXu.  # X * O X o o o X O     @ +   I <X  +   7 &   o o o o o X # % o   & wXvXkXlX",
"lXlXhXCXI.                                =.dX:                               s hXzXkXlX",
"lXlXlXlXcX}.P.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.U.W.sXMX:XL.Y.T.Y.Y.Y.Y.U.(.}.[.{.{.{.].uXvXkXlXlX",
"lXlXlXlXkXBXAXCXBXCXAXAXAXAXAXZXAXCXCXAXZXxXjXmXAXZXVXVXAXZXCXJX'.:.3.5.5.3.:.Q.bXkXlXlX",
"lXlXlXlXlXjXgXxXVXcXgXhXhXhXhXhXfXbXnXgXhXkXlXjXgXlXVXnXhXgXlXyX=             - pXcXkXlX",
"lXlXlXlXlXkXnX;X6.*XnXkXlXlXlXjXVX^.T.VXjXlXlXkXcXuXt.T.bXjXvXwX:   @ %.+.O   : wXvXkXlX",
"lXlXlXlXlXhXZXi.1.y.CXhXlXlXlXjXAXI w.FXhXlXlXkXcXrXc.+.vXjXvXrX,   k L...$   : rXvXkXlX",
"lXlXlXlXlXhXCXu.w.t.NXjXlXlXjXVX`.P n.VXhXlXlXlXjXNX:X*.cXkXvXeX,   m m.u.4   : eXvXkXlX",
"lXlXlXlXlXhXCXB.{ m.VXhXlXlXjXmX$X] 3.AXhXlXlXkXMX*X3.1.fXlXvXeX>   e c.l.1   : eXvXkXlX",
"lXlXlXlXlXlXzXhX.XgXxXlXlXlXlXjXNXcXtXxXlXlXlXlXlXxXXX0XbXjXvXeX:     p w     : eXvXkXlX",
"lXlXlXlXlXlXlXzXBXzXlXlXlXlXlXlXjXkXcXkXlXlXlXlXlXlXBXvXkXkXvXeX:   X     X   : eXvXkXlX",
"lXlXlXlXlXlXlXlXjXlXlXlXlXlXlXlXlXlXkXlXlXlXlXlXlXlXjXkXlXkXvXeX:   . X . .   : eXvXkXlX",
"lXlXlXlXlXlXlXkXhXkXlXlXlXlXlXlXlXhXkXlXlXlXlXlXlXlXhXjXlXkXvXeX:   . O o .   : eXvXkXlX",
"lXlXlXlXlXlXkXvXDXvXkXlXlXlXlXkXcXDXnXkXlXlXlXlXlXxXDXNXkXkXvXeX:         .   : eXvXkXlX",
"lXlXlXlXlXkXvX8Xk.5XbXkXlXlXkXcXeXz.*XbXkXlXlXlXxXdXn.}.bXjXvXeX:   * O.^     : eXvXkXlX",
"lXlXlXlXlXhXZXd.=.a.CXhXlXlXkXnX>X4.5.VXhXlXlXkXbX8Xu.#.cXjXvXeX>   d `.f     : eXvXkXlX",
"lXlXlXlXlXhXCXu.e.y.NXjXlXlXlXgXHX(.8.CXjXlXlXlXhXAX:X*.bXjXvXeX>   5 r.q.=   : eXvXkXlX",
"lXlXlXlXlXhXZXz.X.j.CXhXlXlXjXNX}.q.4.bXkXlXlXkXmX*Xu.-.sXzXcXrX>   > } C.4   > rXvXkXlX",
"lXlXlXlXlXkXcXiXP.yXcXkXlXlXkXzXpXH.5XvXjXlXlXkXlXhXI.=XbXhXvXwX: . o Y b   X : wXvXkXlX",
"lXlXlXlXhXhXgXkXVXlXgXjXkXzXbXvXnXHXNXcXbXcXlXvXvXbXGXVXcXvXnXpX:             : pXcXkXlX",
"lXlXlXzXZXAXAXZXVXZXAXVXzXfX9X0X9X7X9X0X8XyXjX9X0X0X7X8X0X9XqXnXT...#.%.%.#...T.nXkXlXlX",
"lXlXzXgXW.U.Y.U.T.T.P./.zXpX&X-X-X*X*X-X&X5XgX=X=X=X&X*X-X*X<XlXVXGXFXDXDXFXGXVXkXlXlXlX",
"lXkXvXeXo               s.DXcXnXvXVXCXvXnXvXzXnXnXnXJXCXbXnXbXlXjXgXfXvXxXfXgXjXlXlXlXlX",
"lXkXvXrX,   +   p w X   ..FXfXjXvX4X=XvXjXkXlXkXlXhXI.;XbXjXkXlXlXkXbX&X<XbXkXlXlXlXlXlX",
"lXkXvXeX:   o   %X}     $.FXgXhXHX( 6.HXhXlXlXkXmX:Xy.&.jXlXlXlXlXkXNXX.z.DXhXlXlXlXlXlX",
"lXkXvXeX:     B ).H     @.FXfXMX;XW Z.VXhXlXlXlXhXAX1Xe.mXkXlXlXlXjXCX/.V.AXhXlXlXlXlXlX",
"lXkXvXeX:     ` ;X:.    #.FXdXVX^.Z >.AXhXlXlXkXvXqXA [.mXkXlXlXlXjXAXI.z.DXhXlXlXlXlXlX",
"lXkXvXrX,   @   g f     @.FXgXkXmX3XoXnXkXlXlXkXnX3Xa.R.lXlXlXlXlXkXnX1X&XnXkXlXlXlXlXlX",
"lXkXvXeXX               #.GXgXlXkXbXMXkXlXlXlXlXkXvXFXBXlXlXlXlXlXlXkXbXnXkXlXlXlXlXlXlX",
"lXkXcXiXQ G K J L L H E =XnXkXlXlXkXjXlXlXlXlXlXlXkXgXjXlXlXlXlXlXlXlXkXkXlXlXlXlXlXlXlX",
"lXlXlXzXCXZXZXZXZXZXCXAXnXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXhXhXhXhXhXhXhXhXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX"
};

/* XPM */
static const char *const xpm_icon_6[] = {
/* columns rows colors chars-per-pixel */
"32 32 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"lXlXjXjXjXjXjXjXjXjXjXjXjXjXjXjXkXhXjXjXjXjXjXjXjXjXjXjXjXhXlXlX",
"lXkXmXBXMXBXMXMXMXMXMXMXNXNXNXNXvXVXMXBXNXMXMXMXMXMXBXNXMXVXzXlX",
"jXNX~.c n j n m m m n M x v j v.0XS b h x m n m n m k b l %.xXlX",
"gXGXo.    9             * &   A K.    r *           3 O   o eXvX",
"gXDX=.  3 n.&   o o +   N.E   T U.  u H.S   + o +   e.D   1 eXvX",
"gXFX&.    &.:     X   q oXI   Y Y.  h S.[   o   o   P S   , eXvX",
"gXFX$.  O Y - X O O X % { C   I L.  : 2.D   @ O @   n h   > wXvX",
"gXFX;.                        P !.                        # uXcX",
"kXvX6Xa.u.i.i.i.i.i.i.i.a.p.e.#XkXx.y.p.p.i.u.a.b.v.n.m.k.{.bXkX",
"lXkXvXFXFXIXFXFXFXFXFXDXHXHXFXmXzXDXFXIXHXDXHXmX6.| [ } [ h.cXlX",
"lXlXkXhXfX*XdXhXgXgXgXkXrXrXjXjXlXhXgX*XtXfXmX^.    # o   . rXvX",
"lXlXjXBX}. .[.BXjXlXhXDX>.E.ZXjXlXzXjX9.C.BXNX`.  , B.!   < eXvX",
"lXlXhXZXT.#.U.CXhXkXnX5XF ~.VXhXlXkXnX^.j.BXNX'.  0 V.@.  > eXvX",
"lXlXkXmX:X1.-XmXjXkXxXpXh._.BXjXkXcXpXy.W.bXBX`.  @ 3._   > eXvX",
"lXlXlXkXvXxXvXkXlXlXkXcXCXvXkXlXlXlXxXlXvXhXCX`.          ; eXvX",
"lXlXlXlXkXkXkXlXlXlXlXkXhXkXlXlXlXlXlXkXkXjXVX`.  X X X   ; eXvX",
"lXlXlXlXlXvXlXlXlXlXlXlXbXlXlXlXlXlXlXbXzXhXCX`.  X       ; eXvX",
"lXlXlXlXzX0XzXlXlXlXlXkX9XkXlXlXlXlXzX0XhXjXVX`.    3 3   : eXvX",
"lXlXjXNXoXO..XNXjXkXcXuX>.~.VXjXlXxXgX7.G.NXNX`.  > Z.f   > eXvX",
"lXlXhXZXT.$.U.CXhXlXkXNXK.C.AXhXlXkXMX(.j.BXNX`.  = 0.'   > eXvX",
"lXlXjXMX%X%.#XMXjXkXvX9X7.^.NXjXkXxXiXe.K.bXNX`.  O %.%.  < eXvX",
"lXlXhXgXkXiXkXgXjXxXvXbXdXnXvXcXzXcXbXdXbXxXSX_.          o rXvX",
"lXzXDXFXDXHXDXFXmXaXqXwXrXwXqXuXfXqXwXrXwXqXuXiX#.T E ! I r.cXkX",
"xXsXg.y.p.i.i.t.>XdX<X3X2X3X1X0XaX1X3X5X3X2X6XxXSXAXSXSXSXZXlXlX",
"bXwX            ^ GXxXvXMXvXbXcXzXbXnXgXmXbXvXkXhXhXhXgXhXhXlXlX",
"vXeX< o   p.b   ! AXsXSXp.^.VXhXkXxXpXe.G.NXhXlXjXNXi. XBXjXlXlX",
"vXeX>   r  Xl   ~ ZXzXrXP /.VXjXlXkXNX(.L.VXjXlXjXCXH.`.CXjXlXlX",
"vXeX<   y A.C   / ZXzXqX%.R.CXjXkXcXiX) #XnXkXlXjXCX^.}.BXjXlXlX",
"vXwXo           P SXgXbXbXhXzXlXlXzXhX5XeXxXlXlXlXzXgXhXzXlXlXlX",
"cXuXG c N M m l D.BXjXkXkXzXlXlXlXlXzXnXcXlXlXlXlXlXzXzXlXlXlXlX",
"lXzXMXMXMXNXMXBXNXkXlXlXlXlXlXlXlXlXlXkXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXjXjXjXjXjXjXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX"
};

/* XPM */
static const char *const xpm_icon_7[] = {
/* columns rows colors chars-per-pixel */
"24 24 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"zXxXiXaXpXpXpXpXpXsXiXcXvXaXaXpXpXpXpXpXsXiXlXxX",
"VX$.; 5 8 9 8 9 7 3 = 8.C.= 5 7 8 8 9 7 4 < I lX",
"NXc   / @       . [   U -.  [ d       O /   < iX",
"NXF   O.7   @   G W.  ( 3.  C._   + X O %.  q aX",
"NXb   p @       : K   U ;.  P h         i   > iX",
"VX+.& < 2 4 4 5 , = # 5.B.$ ; : 5 3 r a y 0 Q kX",
"zXxXiXhXaXiXpXiXpXhXiXxXvXpXjXfXuXdXQ.j.z.h.].nX",
"lXlXvX7XjXvXcXxXbXyXxXlXkXbX6XpXmXgX2   <   5 dX",
"kXvXwX*.}.MXgXbX2X:.cXkXjXMXK.S.AXuX= d x.% 5 pX",
"kXvXwX$.{.NXgXBX_.#.xXlXkXnXU.Z.ZXiX- i C.1 2 aX",
"lXlXzX<XdXzXlXlXzXeXkXlXlXxX>XeXbXiX3   y   8 pX",
"lXlXlXvXzXlXlXlXkXxXlXlXlXlXbXzXxXpX4       9 pX",
"lXlXzXMXcXkXlXkXvXMXlXlXlXlXmXvXxXpX5       8 pX",
"lXzXhXP.8XvXjXbX2XY.xXlXkXbX^.#XNXiX> 3 ^   8 pX",
"kXnX8X| /.BXhXcXrX0.pXxXjXMXQ.n.SXiX; y h.@ 6 aX",
"kXlXpXp.*XbXhXnX>Xb.hXzXkXbXP.^.VXyX> @ -.> 1 pX",
"zXMXBXCXCXnXlXlXlXxXxXlXlXzXkXxXzXgXt       s hX",
"dX&X%X&X@X4XhX<X1X2X,XqXrX,X4X2X,XdX6X X+X X5XcX",
"$XO       * 2XbXkXkXkXlXkXlXiXkXlXkXnXBXmXBXbXkX",
"$X@   #.h   %XZXwXi.cXlXkXnXY.Y.BXjXzXtXz.jXkXlX",
"&X+ @ W.M   *XHX!.] cXlXjXNXD./.BXjXlXzXV.gXzXlX",
"#X    7 #   $XBXiX#XjXlXkXcXR.1XbXkXlXzX1XkXlXlX",
"<XS B b v W tXcXzXMXlXlXlXkXVXvXkXlXlXlXbXlXlXlX",
"zXNXNXVXNXVXcXkXlXjXlXlXlXlXjXkXlXlXlXlXkXlXlXlX"
};

/* XPM */
static const char *const xpm_icon_8[] = {
/* columns rows colors chars-per-pixel */
"16 16 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"zXxXdXhXjXjXfXxXvXdXgXjXjXdXzXxX",
"NX .p g i p u ' 1.u k u d h Z pX",
"BXd a ,   : ' u V T l     b @ 0X",
"BXN   X   o - z E % :   % 3 w rX",
"cX;X`.]._.`./.*X3XQ.'.^.-./ t.kX",
"jXVX+XpXFXbX*XNXVX5XsX9X- m < wX",
"kXbXv.%XNX6Xb.xXnX_.%X:X1 O.2 qX",
"lXlXxXzXkXxXbXkXlXhXMX-XX   2 qX",
"lXzXfXjXzXhXsXzXzXaXbX-X+ X 1 wX",
"jXbXj.#XBXtXD.lXNX).%X<X3 | 2 qX",
"lXAX>XgXMXaX#XzXbX:XrX,X  6 = wX",
"gX{._.`.eXtXdXrXtXiXiXrXI.M.E.kX",
"wX$ 5   S.BXOXlXvX,X5XnXNXeXAXlX",
"eXX ( > n.jXj.vXMX/.%XMXsX(.kXlX",
"rXm i e /.VXfXlXzXuXgXzXlXkXlXlX",
"lXjXhXkXcXlXzXlXlXcXzXlXlXzXlXlX"
};

const char *const *const xpm_icons[] = {
    xpm_icon_0,
    xpm_icon_1,
    xpm_icon_2,
    xpm_icon_3,
    xpm_icon_4,
    xpm_icon_5,
    xpm_icon_6,
    xpm_icon_7,
    xpm_icon_8,
};
const int n_xpm_icons = 9;
